@@ -9,6 +9,9 @@
  * Based on information from the cm4000 driver by Omnikey AG.
  */
 
+/* only available on linux */
+#ifdef linux
+
 #include "cardman.h"
 #include "internal.h"
 #include <stdlib.h>
@@ -23,7 +26,7 @@
 static int cm_open(ifd_reader_t * reader, const char *device_name)
 {
 	ifd_device_t *dev;
-        ifd_device_params_t params;
+	ifd_device_params_t params;
 
 	reader->name = "OMNIKEY CardMan 4000";
 	reader->nslots = 1;
@@ -163,3 +166,14 @@ void ifd_cm4000_register(void)
 
 	ifd_driver_register("cm4000", &cm4000_driver);
 }
+
+#else
+
+/*
+ * Initialize this module
+ */
+void ifd_cm4000_register(void)
+{
+}
+
+#endif
