@@ -113,6 +113,7 @@ extern struct ifd_protocol_ops ifd_protocol_i2c_long;
 extern struct ifd_protocol_ops ifd_protocol_2wire;
 extern struct ifd_protocol_ops ifd_protocol_3wire;
 extern struct ifd_protocol_ops ifd_protocol_eurochip;
+extern struct ifd_protocol_ops ifd_protocol_esc;
 
 extern void ifd_acr30u_register(void);
 extern void ifd_cardman_register(void);
@@ -132,7 +133,7 @@ extern void ifd_smartboard_register(void);
 extern void ifd_smph_register(void);
 extern void ifd_starkey_register(void);
 extern void ifd_towitoko_register(void);
-extern void ifd_wbeiuu_register(void);
+/* extern void ifd_wbeiuu_register(void); driver not working yet */
 
 /* reader.c */
 extern int ifd_send_command(ifd_protocol_t *, const void *, size_t);
