@@ -11,7 +11,7 @@
  */
 
 #include "internal.h"
-#if defined(__NetBSD__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__NetBSD__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)
 #include <sys/types.h>
 #include <dev/usb/usb.h>
 #include <sys/stat.h>
@@ -20,6 +20,7 @@
 #include <sys/file.h>
 #include <string.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <signal.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -73,6 +74,7 @@ int open_ep(char *name, int interface, int endpoint, int flags)
 	return 0;
 }
 
+static void
 close_ep(int interface, int endpoint)
 {
 	if (interfaces[interface][endpoint].ep_fd) {
@@ -312,7 +314,7 @@ int ifd_sysdep_usb_release_interface(ifd_device_t * dev, int interface)
 
 int ifd_sysdep_usb_open(const char *device)
 {
-        return open(device, O_RDWR);
+	return open(device, O_RDWR);
 }
 
 int ifd_sysdep_usb_reset(ifd_device_t * dev)
@@ -376,15 +378,19 @@ int ifd_scan_usb(void)
 				  device_info.udi_product,
 				  device_info.udi_productNo);
 
+			/* FIXME: if we don't find a driver with vendor/product
+			 * then check for the interface type (ccid) and use
+			 * driver ccid... */
+
 			if (!(driver = ifd_driver_for_id(&id)))
 				continue;
 #ifdef __OpenBSD__
 			snprintf(typedev, sizeof(typedev),
-				"usb:/dev/%s.00", device_info.udi_devnames[0]);
+				 "usb:/dev/%s.00", device_info.udi_devnames[0]);
 #else
 			snprintf(typedev, sizeof(typedev),
 				 "usb:/dev/%s", device_info.udi_devnames[0]);
-#endif	/* __OpenBSD__ */
+#endif				/* __OpenBSD__ */
 
 			ifd_spawn_handler(driver, typedev, -1);
 		}
