@@ -160,7 +160,7 @@ int ifd_sysdep_usb_poll_presence(ifd_device_t * dev, struct pollfd *pfd)
  */
 int ifd_sysdep_usb_control(ifd_device_t * dev, unsigned int requesttype,
 			   unsigned int request, unsigned int value,
-			   unsigned int index, void *data, size_t len,
+			   unsigned int idx, void *data, size_t len,
 			   long timeout)
 {
 	struct usbdevfs_ctrltransfer ctrl;
@@ -169,7 +169,7 @@ int ifd_sysdep_usb_control(ifd_device_t * dev, unsigned int requesttype,
 	ctrl.bRequestType = requesttype;
 	ctrl.bRequest = request;
 	ctrl.wValue = value;
-	ctrl.wIndex = index;
+	ctrl.wIndex = idx;
 	ctrl.wLength = len;
 	ctrl.data = data;
 	ctrl.timeout = timeout;
@@ -404,8 +404,34 @@ int ifd_scan_usb(void)
 			id.val[0] = dev->descriptor.idVendor;
 			id.val[1] = dev->descriptor.idProduct;
 
-			if (!(driver = ifd_driver_for_id(&id)))
-				continue;
+			/* FIXME: if we don't find a driver with vendor/product
+ 			 * then check for the interface type (ccid) and use
+ 			 * driver ccid... */
+
+			if (!(driver = ifd_driver_for_id(&id))) {
+				/* no driver found, check for interface class */
+				int ccid=0;
+				int conf;
+ 				for (conf = 0; conf < 
+					dev->descriptor.bNumConfigurations;
+					conf++) {
+				int interf;
+  				for (interf = 0; interf <
+					dev->config[conf].bNumInterfaces;
+					interf++) {
+				int alt;
+				for (alt = 0; alt < dev->config[conf].interface[interf].num_altsetting; alt++) {
+					if (dev->config[conf].interface[interf].altsetting[alt].bInterfaceClass == 0x0b) {
+					ccid=1;
+				}
+				}
+				}	
+				}
+					
+				/* not a ccid device */
+				if (!ccid)
+					continue;
+			}
 
 			snprintf(typedev, sizeof(typedev),
 				 "/dev/bus/usb/%s/%s",
