@@ -15,7 +15,7 @@
  */
 int ifd_usb_control(ifd_device_t * dev, unsigned int requesttype,
 		    unsigned int request, unsigned int value,
-		    unsigned int index, void *buffer, size_t len, long timeout)
+		    unsigned int idx, void *buffer, size_t len, long timeout)
 {
 	int n;
 
@@ -27,18 +27,18 @@ int ifd_usb_control(ifd_device_t * dev, unsigned int requesttype,
 	if ((ct_config.debug >= 3) && !(requesttype & 0x80)) {
 		ifd_debug(4,
 			  "usb req type=x%02x req=x%02x val=x%04x ind=x%04x len=%u",
-			  requesttype, request, value, index, len);
+			  requesttype, request, value, idx, len);
 		if (len)
 			ifd_debug(4, "send %s", ct_hexdump(buffer, len));
 	}
 
-	n = ifd_sysdep_usb_control(dev, requesttype, request, value, index,
+	n = ifd_sysdep_usb_control(dev, requesttype, request, value, idx,
 				   buffer, len, timeout);
 
 	if ((ct_config.debug >= 3) && (requesttype & 0x80)) {
 		ifd_debug(4,
 			  "usb req type=x%02x req=x%02x val=x%04x ind=x%04x len=%d",
-			  requesttype, request, value, index, n);
+			  requesttype, request, value, idx, n);
 		if (n > 0)
 			ifd_debug(4, "recv %s", ct_hexdump(buffer, n));
 	}
@@ -170,13 +170,11 @@ static int usb_reset(ifd_device_t * dev)
 {
 	int rc;
 
-	rc = ifd_sysdep_usb_reset( dev );
+	rc = ifd_sysdep_usb_reset(dev);
 
 	return rc;
 }
 
-
-
 static struct ifd_device_ops ifd_usb_ops;
 
 /*
@@ -191,7 +189,7 @@ ifd_device_t *ifd_open_usb(const char *device)
 		ct_error("Unable to open USB device %s: %m", device);
 		return NULL;
 	}
-	
+
 	ifd_usb_ops.poll_presence = ifd_sysdep_usb_poll_presence;
 	ifd_usb_ops.set_params = usb_set_params;
 	ifd_usb_ops.send = usb_send;
